@@ -261,7 +261,8 @@ If LOAD is true, load the fasl file."
     swank-mrepl
     swank-trace-dialog
     swank-macrostep
-    swank-quicklisp)
+    swank-quicklisp
+    swank-indentation)
   "List of names for contrib modules.")
 
 (defun append-dir (absolute name)
@@ -354,8 +355,8 @@ global variabes in SWANK."
   (when setup
     (setup)))
 
-(defun dump-image (filename)
-  (init :setup nil)
+(defun dump-image (filename &key load-contribs)
+  (init :setup nil :load-contribs load-contribs)
   (funcall (q "swank/backend:save-image") filename))
 
 (defun list-fasls (&key (include-contribs t) (compile t)
