@@ -940,3 +940,7 @@ Execute BODY with NAME's function slot set to FUNCTION."
              (setf *log-output* nil))
            (swank::init-log-output))
          custom:*init-hooks*)
+
+(defimplementation structure-accessor-p (symbol)
+  (and (get symbol 'system::defstruct-reader)
+       t))
